@@ -7,6 +7,7 @@
 *******************************************************************************/
 
 #include "pimutil.h"
+using namespace Qt::Literals::StringLiterals;
 
 #include "imapresourcesettings.h"
 
@@ -26,7 +27,7 @@
 OrgKdeAkonadiImapSettingsInterface *PimCommon::Util::createImapSettingsInterface(const QString &ident)
 {
     if (isImapResource(ident)) {
-        return new OrgKdeAkonadiImapSettingsInterface(QLatin1String("org.freedesktop.Akonadi.Resource.") + ident,
+        return new OrgKdeAkonadiImapSettingsInterface("org.freedesktop.Akonadi.Resource."_L1 + ident,
                                                       QStringLiteral("/Settings"),
                                                       QDBusConnection::sessionBus());
     } else {
@@ -133,7 +134,7 @@ QStringList PimCommon::Util::generateEmailList(const QStringList &list)
         QString tmpStr = list.at(i);
         if (!tmpStr.trimmed().isEmpty()) {
             if (!str.isEmpty()) {
-                str.append(QLatin1String(", "));
+                str.append(", "_L1);
             }
             str.append(tmpStr);
         }
